@@ -3,6 +3,7 @@ from .models.exception import *
 from .models.json_schema import JSONSchema
 from .models.user import User
 from .models.transaction import Transaction
+from .models.payment import Payment, PaymentStatus
 from .models.payment_method import (PaymentMethod, PaymentRole, PaymentPrivacy)
 from .utils.api_util import (deserialize, wrap_callback, warn, get_user_id, confirm, validate_access_token)
 from .utils.api_client import ApiClient
@@ -13,9 +14,10 @@ from .venmo import Client
 
 __all__ = ["AuthenticationFailedError", "InvalidArgumentError", "InvalidHttpMethodError", "ArgumentMissingError",
            "JSONDecodeError", "ResourceNotFoundError", "HttpCodeError", "NoPaymentMethodFoundError",
-           "string_to_timestamp", "get_phone_model_from_json", "random_device_id", "deserialize", "wrap_callback",
-           "warn", "confirm", "get_user_id", "validate_access_token",
-           "JSONSchema", "User", "Transaction", "PaymentMethod", "PaymentRole", "PaymentPrivacy",
-           "ApiClient", "AuthenticationApi", "UserApi", "PaymentApi",
+           "NoPendingPaymentToUpdateError", "AlreadyRemindedPaymentError", "string_to_timestamp",
+           "get_phone_model_from_json", "random_device_id",
+           "deserialize", "wrap_callback", "warn", "confirm", "get_user_id", "validate_access_token",
+           "JSONSchema", "User", "Transaction", "Payment", "PaymentStatus", "PaymentMethod", "PaymentRole",
+           "PaymentPrivacy", "ApiClient", "AuthenticationApi", "UserApi", "PaymentApi",
            "Client"
            ]
