@@ -63,6 +63,6 @@ class User(object):
                    is_active=parser.get_is_active())
 
     def __str__(self):
-        return f'id: {self.id}, username: {self.username}, firstname: {self.first_name}, lastname: {self.last_name}'\
-            f' display_name: {self.display_name}, phone: {self.phone}, picture: {self.profile_picture_url}, about: {self.about},'\
+        return f'User: id: {self.id}, username: {self.username}, first_name: {self.first_name}, last_name: {self.last_name}'\
+            f' display_name: {self.display_name}, phone: {self.phone}, profile_picture_url: {self.profile_picture_url}, about: {self.about},'\
             f' joined: {self.date_joined}, is_group: {self.is_group}, is_active: {self.is_active}'
